@@ -2,7 +2,7 @@ plotEnergy <-
 function(energy, show.total=TRUE, ...) {
 ###	plotting wind energy rose
 	
-	if(is.null(attr(energy, "call")$func)) stop(paste(substitute(energy), "is no energy object\n"))
+	if(is.null(attr(energy, "call"))) stop(paste(substitute(energy), "is no energy object\n"))
 	if(attr(energy, "call")$func!="energy") stop(paste(substitute(energy), "is no energy object\n"))
 	
 	dim.data <- dim(energy)
