@@ -2,7 +2,7 @@ plotFrequency <-
 function(freq, ...) {
 ### plotting frequency from frequency object
 	
-	if(is.null(attr(freq, "call")$func)) stop(paste(substitute(freq), "is no frequency object\n"))
+	if(is.null(attr(freq, "call"))) stop(paste(substitute(freq), "is no frequency object\n"))
 	if(attr(freq, "call")$func!="frequency") stop(paste(substitute(freq), "is no frequency object\n"))
 	 
 	dim.data <- dim(freq)
