@@ -2,14 +2,28 @@ plotWeibull <-
 function(wb, show.ak=FALSE, ...) {
 ### plotting fitted weibull distribution from weibull object
 	
-	if(is.null(attr(wb, "call")$func)) stop(paste(substitute(wb), "is no weibull object\n"))
+	if(is.null(attr(wb, "call"))) stop(paste(substitute(wb), "is no weibull object\n"))
 	if(attr(wb, "call")$func!="weibull") stop(paste(substitute(wb), "is no weibull object\n"))
 	
 	if(is.null(attr(wb, "call")$mast)) stop(paste("Source mast object of", substitute(wb), "could not be found\n"))
 	mast <- get(attr(wb, "call")$mast)
 	v.set <- attr(wb, "call")$v.set
+	subset <- attr(wb, "call")$subset
 	unit <- attr(mast$sets[[v.set]]$data$v.avg, "unit")
 	
+	# subset
+	num.samples <- length(mast$time.stamp)
+	start <- strptime(subset[1], "%Y-%m-%d %H:%M:%S")
+	end <- strptime(subset[2], "%Y-%m-%d %H:%M:%S")
+	if(is.na(start)) start <- strptime(subset[1], "%Y-%m-%d %H:%M")
+	if(is.na(end)) end <- strptime(subset[2], "%Y-%m-%d %H:%M")
+	if(is.na(start)) start <- strptime(subset[1], "%Y-%m-%d %H")
+	if(is.na(end)) end <- strptime(subset[2], "%Y-%m-%d %H")
+	match.date <- difftime(mast$time.stamp, ISOdatetime(1,1,1,0,0,0), tz="GMT", units="days") - difftime(start, ISOdatetime(1,1,1,0,0,0), tz="GMT", units="days")
+	start <- which(abs(as.numeric(match.date)) == min(abs(as.numeric(match.date))))
+	match.date <- difftime(mast$time.stamp, ISOdatetime(1,1,1,0,0,0), tz="GMT", units="days") - difftime(end, ISOdatetime(1,1,1,0,0,0), tz="GMT", units="days")
+	end <- which(abs(as.numeric(match.date)) == min(abs(as.numeric(match.date))))
+	
 	plot.param <- list(...)
 	if(any(names(plot.param)=="col")) col <- plot.param$col
 	else col <- "#3182BD"
@@ -48,7 +62,7 @@ function(wb, show.ak=FALSE, ...) {
 	if(any(names(plot.param)=="pos.leg")) pos.leg <- plot.param$pos.leg
 	else pos.leg <- "topright"
 	if(any(names(plot.param)=="breaks")) breaks <- plot.param$breaks
-	else breaks <- seq(0, ceiling(max(mast$sets[[v.set]]$data$v.avg, na.rm=TRUE)), 1)
+	else breaks <- seq(0, ceiling(max(mast$sets[[v.set]]$data$v.avg[start:end], na.rm=TRUE)), 1)
 	if(any(names(plot.param)=="xlab")) xlab <- plot.param$xlab
 	else xlab <- paste("Wind speed [", unit, "]", sep="")
 	if(any(names(plot.param)=="ylab")) ylab <- plot.param$ylab
@@ -70,7 +84,7 @@ function(wb, show.ak=FALSE, ...) {
 	if(any(names(plot.param)=="leg.text")) leg.text <- plot.param$leg.text
 	else leg.text <- c("measured", "Weibull")
 	
-	density <- hist(mast$sets[[v.set]]$data$v.avg, breaks=breaks, plot=FALSE)$density
+	density <- hist(mast$sets[[v.set]]$data$v.avg[start:end], breaks=breaks, plot=FALSE)$density
 	
 	# prepare plot
 	old.par <- par(no.readonly=TRUE)
@@ -79,7 +93,7 @@ function(wb, show.ak=FALSE, ...) {
 	# plot
 	par(mar=mar, mgp=mgp, las=las, bty="n")
 	plot.new()
-	hist(mast$sets[[v.set]]$data$v.avg, breaks=breaks, axes=FALSE, freq=FALSE, col=col, border=border, main=NULL, xlab=xlab, ylab=ylab, cex.lab=cex.lab, col.lab=col.lab, xlim=xlim, ylim=ylim)
+	hist(mast$sets[[v.set]]$data$v.avg[start:end], breaks=breaks, axes=FALSE, freq=FALSE, col=col, border=border, main=NULL, xlab=xlab, ylab=ylab, cex.lab=cex.lab, col.lab=col.lab, xlim=xlim, ylim=ylim)
 	box(bty=bty, col=col.box)
 	axis(1, col=col.ticks, col.axis=col.axis, cex.axis=cex.axis)
 	if(!is.null(ylim)) axis(2, at=seq(ylim[1], ylim[2], 0.02), labels=seq(ylim[1]*100, ylim[2]*100, 2), col=col.ticks, col.axis=col.axis, cex.axis=cex.axis)
@@ -89,7 +103,6 @@ function(wb, show.ak=FALSE, ...) {
 	curve(dweibull(x, shape=tail(wb$k, 1), scale=tail(wb$A, 1)), col=line, lty=lty, lwd=lwd, add=TRUE)
 	
 	if(legend) {
-		
 		if(show.ak) leg <- c(leg.text[1], paste(leg.text[2], " (A:", round(tail(wb$A, 1), digits=1), ", k:", round(tail(wb$k, 1), digits=1), ")", sep=""))
 		legend(pos.leg, legend=leg.text, col=c(border, line), lty=c(NA, lty), lwd=c(NA, lwd), pch=c(22, NA), pt.bg=c(col, NA), bty=bty.leg, cex=cex.leg, text.col=col.leg, x.intersp=x.intersp, y.intersp=y.intersp)
 	}
